@@ -1,15 +1,19 @@
 package Catmandu::Fix::wd_simple;
 #ABSTRACT: Simplify Wikidata entity records
-our $VERSION = '0.05'; #VERSION
+our $VERSION = '0.06'; #VERSION
 use Catmandu::Sane;
 use Moo;
 
 use Catmandu::Fix::wd_simple_strings;
 use Catmandu::Fix::wd_simple_claims;
+use Catmandu::Fix::wd_language as => 'wd_language';
+
+has language => (is => 'ro', required => 0);
 
 sub fix {
     my ($self, $data) = @_;
 
+    wd_language($data, $self->language) if $self->language;
     Catmandu::Fix::wd_simple_strings::fix($self,$data);
     Catmandu::Fix::wd_simple_claims::fix($self,$data);
 
@@ -36,7 +40,12 @@ Catmandu::Fix::wd_simple - Simplify Wikidata entity records
 
 =head1 VERSION
 
-version 0.05
+version 0.06
+
+=head1 SYNOPSIS
+
+    wd_simple()
+    wd_simple(language:"de")
 
 =head1 DESCRIPTION
 
